package com.xqopen.kehui.admin.action;

import java.util.Arrays;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.support.spring.FastJsonJsonView;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.baomidou.mybatisplus.plugins.Page;
import com.xqopen.kehui.Api;
import com.xqopen.kehui.admin.api.AdminDocumentManagementApi;
import com.xqopen.kehui.admin.dto.AdminDocumentManageListItem;
import com.xqopen.kehui.admin.dto.AdminDocumentManagementDto;
import com.xqopen.kehui.admin.dto.AdminDocumentManagementListReq;
import com.xqopen.kehui.admin.dto.AdminDocumentManagementListResp;
import com.xqopen.kehui.admin.dto.AdminDocumentManagementReq;
import com.xqopen.kehui.admin.entity.AdminDocumentManagement;
import com.xqopen.kehui.admin.service.IAdminDocumentManagementService;
import com.xqopen.kehui.admin.unit.adminEnum;
import com.xqopen.kehui.common.dto.BatchDelIdsReq;
import com.xqopen.kehui.common.dto.SystemOrgItem;
import com.xqopen.kehui.common.entity.SystemTerm;
import com.xqopen.kehui.common.entity.SystemUserLogin;
import com.xqopen.kehui.common.service.*;
import com.xqopen.kehui.exception.ErrorCode;
import com.xqopen.kehui.exception.XQException;
import com.xqopen.kehui.flows.service.BaseActivitiApi;
import com.xqopen.kehui.flows.service.IFlowsService;
import com.xqopen.kehui.flows.util.activitiEnum;
import com.xqopen.kehui.util.ApiResponse;
import com.xqopen.kehui.util.CalendarTest;
import com.xqopen.kehui.util.JacksonUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.logging.log4j.util.Strings;


import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;


/**
 * <p>
 * 公文管理 前端控制器
 * </p>
 *
 * @author jason@xqopen.cn
 * @since 2017-11-27
 */
@Slf4j
@RestController
@RequestMapping(produces = FastJsonJsonView.DEFAULT_CONTENT_TYPE)
public class AdminDocumentManagementController implements AdminDocumentManagementApi {
    @Autowired
    ISystemContentService contentService;

    @Autowired
    IAdminDocumentManagementService managementService;

    @Autowired
    ISystemOrgService orgService;

    @Autowired
    ISystemUserLoginService loginService;

    @Autowired
    BaseActivitiApi activitiApi;

    @Autowired
    IFlowsService flowsService;

    @Autowired
    ISystemTermService systemTermService;

    @Autowired
    ISystemRoleService roleService;

    @GetMapping(Api.GET_ADMIN_DOCUMENT_MANAGEMENT)
    public String get(@RequestHeader("userId") Long userId, @PathVariable("id") Long id) throws XQException {
        try {
            AdminDocumentManagementDto managementDto = managementService.getDocumentBaseList(id);
            if (managementDto.getDocumentType() == 2) {
//                managementDto.setIsUploadPdf(flowsService.isEdit(id, userId, activitiEnum.activitiType.postDocument.name()));
                Boolean isArchivist = !roleService.getSystemRoleByRoleTagAUserId("archivist", userId).isEmpty();
                if (managementDto.getActivitiStatus().equals(2L) && (managementDto.getCreatedBy().equals(userId) || isArchivist)) {
                    managementDto.setIsUploadPdf(true);
                } else {
                    managementDto.setIsUploadPdf(false);
                }
                if (managementDto.getActivitiStatus().equals(3L) && (managementDto.getCreatedBy().equals(userId) || isArchivist)) {
                    managementDto.setIsEdit(true);
                }else{
                    managementDto.setIsEdit(flowsService.isEdit(id, userId, ""));
                }
            } else {
                managementDto.setIsUploadPdf(false);
            }
            managementDto.setIsBack(flowsService.isBack(id, userId));
            managementDto.setApproveRole(flowsService.getApprover(id, userId));
            if (!StringUtils.isEmpty(managementDto.getContentClass())) {
                adminEnum.receiveClass admin = Enum.valueOf(adminEnum.receiveClass.class, managementDto.getContentClass());
                if (admin != null) {
                    managementDto.setContentClassName(admin.getValue());
                }
            }
            return ApiResponse.fillSuccess(managementDto);
        } catch (Exception e) {
            log.error("AdminDocumentManagementController.get", e);
            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_EXCEPTION_ERROR, null);
        }
    }

    @PostMapping(Api.ADD_ADMIN_DOCUMENT_MANAGEMENT)
    public String add(@RequestHeader("userId") Long userId, @RequestBody AdminDocumentManagementReq managementReq)
            throws XQException {
//        try {
        String receiveTitle = managementReq.getContentTitle();
        String receiveClass = managementReq.getContentClass();
        String content = managementReq.getContent();
        String receiveNum = managementReq.getReceiveNum();
        Boolean isSigned = false;
        JSONObject ext = managementReq.getExt();
        if (ext.containsKey("isSigned")) {
            isSigned = ext.getBoolean("isSigned");
        }
        if (StringUtils.isEmpty(receiveTitle)) {
            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_TITLE_EMPTY_ERROR, null);
        }
        if (StringUtils.isEmpty(receiveClass)) {
            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_CLASS_EMPTY_ERROR, null);
        }

       /* if (!receiveNum.isEmpty() && managementReq.getDocumentType() == 2 && managementService.isExistByReceiveNum(receiveNum, 0L) > 0) {
            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_RECEIVENUM_EXITS_ERROR, null);
        }*/
        String module = getBelongModule(receiveClass);

        Long contentId = contentService.add(receiveClass, module, receiveTitle, content, userId);
        AdminDocumentManagement management = new JacksonUtil<AdminDocumentManagement>()
                .setAddEntity(userId, managementReq, AdminDocumentManagement.class);
        management.setContentId(contentId);
        managementService.insert(management);

        //添加审批
        if (managementReq.getDocumentType() == 2) { //发文
            /**
             * 流程修改2022-02-27
             * 增加一级判断，分类判断，若为成果评价类型，则按新流程
             */
            if(ext.get("contentClass").equals("cgPj")){
                activitiApi.startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentCgPj, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentCgPj);
            }else if(ext.get("contentClass").equals("djKy")){
                activitiApi.startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentDjKy, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentDjKy);
            }else{
                /*鄂技协\鄂技协纪要发文*/
                if(ext.get("CategoryID").equals("978108623924236290") || ext.get("CategoryID").equals("978108532228362241")){
                    activitiApi.startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentXh, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentXh);
                }else if(ext.get("CategoryID").equals("976655785889185793")//鄂技交函
                        || ext.get("CategoryID").equals("976656138147807234")//鄂技交业
                        || ext.get("CategoryID").equals("978255291938586738")//无文号
                        || ext.get("CategoryID").equals("978255291938586739")//鄂技交办
                        || ext.get("CategoryID").equals("976655699536855042")){//鄂技交发
                    activitiApi
                            .startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentHywbf, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentHywbf);
                }else if(ext.get("CategoryID").equals("976656401982111746")){//鄂技交工
                    activitiApi.startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentGong, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentGong);
                }else if(ext.get("CategoryID").equals("978255291938586740")){//鄂技交办公纪要
                    activitiApi.startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentBGJY, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentBGJY);
                }else if(ext.get("CategoryID").equals("976656351180701697")){//鄂技交党总支会议纪要
                    activitiApi.startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentDZZJY, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentDZZJY);
                }else if(ext.get("CategoryID").equals("976656222025498625")){//鄂技交党
                    activitiApi.startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentDang, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentDang);
                }else if(ext.get("CategoryID").equals("976656263691714561")){//鄂技交纪
                    activitiApi.startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentJi, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentJi);
                }else if(ext.get("CategoryID").equals("976656079536603137") || ext.get("CategoryID").equals("976656179017105409")){//鄂技交人\财
                    activitiApi.startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentRenCai, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentRenCai);
                }else if(ext.get("CategoryID").equals("976655291938586626")){//鄂技交文
                    activitiApi.startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentWen, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentWen);
                }
                else{
                    activitiApi
                            .startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocument, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocument);
                }
            }
            /*if(ext.get("draftDeptName").equals("湖北技术市场协会>技术转移中心") || ext.get("draftDeptName").equals("湖北技术市场协会>培训服务中心") || ext.get("draftDeptName").equals("湖北技术市场协会>综合管理办公室")){
                activitiApi
                        .startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentXh, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentXh);
            }else{
                if(ext.get("CategoryID").equals("976655785889185793")//鄂技交文
                        || ext.get("CategoryID").equals("976656138147807234")//鄂技交发
                        || ext.get("CategoryID").equals("978255291938586738")//无文号
                        || ext.get("CategoryID").equals("978255291938586739")){//鄂技交办
                    activitiApi
                            .startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentHywbf, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentHywbf);
                }else if(ext.get("CategoryID").equals("976656401982111746")){
                    activitiApi
                            .startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocumentGong, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocumentGong);
                }else{
                    activitiApi
                            .startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocument, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocument);
                }
            }*/


           /* activitiApi
                    .startWorkflow(userId, management.getId(), activitiEnum.activitiType.postDocument, isSigned ? activitiEnum.activitiClass.signedDocument : activitiEnum.activitiClass.postDocument);*/

        } else {
            activitiApi
                    .startWorkflow(userId, management.getId(), activitiEnum.activitiType.received, activitiEnum.activitiClass.receivedDocument);
        }
        return ApiResponse.fillSuccess("添加成功");
//        } catch (Exception e) {
//            log.error("AdminDocumentManagementController.add", e);
//            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_EXCEPTION_ERROR, null);
//        }
    }

    @PutMapping(Api.EDIT_ADMIN_DOCUMENT_MANAGEMENT)
    public String edit(@RequestHeader("userId") Long userId, @RequestBody AdminDocumentManagementReq managementReq,
                       @PathVariable("id") Long id) throws XQException {
//        try {
        String receiveTitle = managementReq.getContentTitle();
        String receiveClass = managementReq.getContentClass();
        String content = managementReq.getContent();
        String receiveNum = managementReq.getReceiveNum();
        if (StringUtils.isEmpty(receiveTitle)) {
            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_TITLE_EMPTY_ERROR, null);
        }
        if (StringUtils.isEmpty(receiveClass)) {
            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_CLASS_EMPTY_ERROR, null);
        }
        /*if (!receiveNum.isEmpty() && managementReq.getDocumentType() == 2 && managementService.isExistByReceiveNum(receiveNum, id) > 0) {
            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_RECEIVENUM_EXITS_ERROR, null);
        }*/
        String module = getBelongModule(receiveClass);
        Wrapper<AdminDocumentManagement> wrapper = new EntityWrapper<>();
        wrapper.eq(AdminDocumentManagement.ID_, id);
        wrapper.eq(AdminDocumentManagement.IS_DELETED, false);
        AdminDocumentManagement management = managementService.selectOne(wrapper);
        if (management == null) {
            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_EMPTY_ERROR, null);
        }
        Long contentId = contentService.edit(receiveClass, module, receiveTitle, content, userId, management.getContentId());
        management.setExt(managementReq.getExt());
        management.setUpdatedAt(new Date());
        management.setUpdatedBy(userId);
        managementService.update(management, wrapper);
        if (StringUtils.isEmpty(managementReq.getActivitiFrom())) {
            managementReq.setActivitiFrom("");
        }

        return activitiApi.auto2Job(managementReq.getActivitiFrom(), userId, managementReq.getTaskId(), managementReq.getComment(), id,managementReq.getExt().getString("CategoryID"),id);

//        } catch (Exception e) {
//            log.error("AdminDocumentManagementController.edit", e);
//            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_EXCEPTION_ERROR, null);
//        }
    }

    @DeleteMapping(Api.DEL_ADMIN_DOCUMENT_MANAGEMENT)
    public String del(@RequestHeader("userId") Long userId, @RequestBody BatchDelIdsReq idsReq)
            throws XQException {
        try {
            List<AdminDocumentManagement> list = new JacksonUtil<AdminDocumentManagement>()
                    .getDelList(userId, idsReq, AdminDocumentManagement.class);
            managementService.updateBatchById(list);
            return ApiResponse.fillSuccess(null);
        } catch (Exception e) {
            log.error("AdminDocumentManagementController.del", e);
            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_EXCEPTION_ERROR, null);
        }
    }

    @PostMapping(Api.LIST_ADMIN_DOCUMENT_MANAGEMENT)
    public String list(@RequestHeader("userId") Long userId,
                       @RequestBody AdminDocumentManagementListReq listReq,
                       @RequestParam(value = "pageNo", required = false) Integer pageNo,
                       @RequestParam(value = "pageSize", required = false) Integer pageSize)
            throws XQException {
        try {
            if (pageNo == null || pageNo == 0) {
                pageNo = 1;
            }
            if (pageSize == null || pageSize == 0) {
                pageSize = 10;
            }
            Date beginDate = StringUtils.isEmpty(listReq.getBeginDate()) ? null : CalendarTest.StrToDate(listReq.getBeginDate());
            Date endDate = StringUtils.isEmpty(listReq.getEndDate()) ? null : CalendarTest.StrToDate(listReq.getEndDate());
            Page<AdminDocumentManageListItem> page = new Page<>(pageNo, pageSize);
            List<AdminDocumentManageListItem> list = managementService
                    .getDocumentList(page, listReq.getDocumentType(), listReq.getReceiveClass(), listReq.getSeachValue(), listReq.getApproveStatus(), userId, beginDate, endDate);
            for (AdminDocumentManageListItem listItem : list) {
                if (!StringUtils.isEmpty(listItem.getContentClass())) {
                    adminEnum.receiveClass admin = Enum.valueOf(adminEnum.receiveClass.class, listItem.getContentClass());
                    if (admin != null) {
                        listItem.setContentClassName(admin.getValue());
                    }
                    Wrapper<SystemUserLogin> wrapper = new EntityWrapper<>();
                    wrapper.eq(SystemUserLogin.USERINFO_ID, listItem.getPersonId());
                    wrapper.eq(SystemUserLogin.IS_DELETED, false);
                    SystemUserLogin login = loginService.selectOne(wrapper);
                    if (login != null) {
                        SystemOrgItem orgItem = orgService.getOrgNameListByUserId(login.getId());
                        if (orgItem != null) {
                            listItem.setOrgName(orgItem.getOrgName());
                        }
                    }
                }

                listItem.setIsRead(JacksonUtil.getIsRead(listItem.getExt(), userId.toString()));
                Boolean isOffice = !roleService.getSystemRoleByRoleTagAUserId("office", userId).isEmpty();
                Boolean isDirector = !roleService.getSystemRoleByRoleTagAUserId("director", userId).isEmpty();
                Boolean isBranch = !roleService.getSystemRoleByRoleTagAUserId("branchLeader", userId).isEmpty();
                Boolean isArchivist = !roleService.getSystemRoleByRoleTagAUserId("archivist", userId).isEmpty();
                if (listItem.getActivitiStatus().equals(2L) && (listItem.getCreatedBy().equals(userId) || isArchivist)) {
                    listItem.setShowUpLoad(true);
                } else {
                    listItem.setShowUpLoad(false);
                }
                if (listItem.getActivitiStatus().equals(2L) && listItem.getExt().containsKey("formalFile") && listItem.getExt().get("formalFile") != null
                        && (listItem.getCreatedBy().equals(userId) || isArchivist || isOffice || isDirector || isBranch)) {
                    listItem.setShowDownLoad(true);
                } else {
                    listItem.setShowDownLoad(false);
                }
            }
            AdminDocumentManagementListResp resp = new AdminDocumentManagementListResp();
            resp.setLs(list);
            resp.setPages(page.getPages());
            resp.setTotal(page.getTotal());

            return ApiResponse.fillSuccess(resp);
        } catch (Exception e) {
            log.error("AdminDocumentManagementController.edit", e);
            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_EXCEPTION_ERROR, null);
        }
    }

    @PostMapping(Api.LIST_ADMIN_DOCUMENT_MANAGEMENT_NOTICE)
    public String listNotice(@RequestHeader("userId") Long userId,
                       @RequestBody AdminDocumentManagementListReq listReq,
                       @RequestParam(value = "pageNo", required = false) Integer pageNo,
                       @RequestParam(value = "pageSize", required = false) Integer pageSize)
            throws XQException {
        try {
            if (pageNo == null || pageNo == 0) {
                pageNo = 1;
            }
            if (pageSize == null || pageSize == 0) {
                pageSize = 10;
            }
            Date beginDate = StringUtils.isEmpty(listReq.getBeginDate()) ? null : CalendarTest.StrToDate(listReq.getBeginDate());
            Date endDate = StringUtils.isEmpty(listReq.getEndDate()) ? null : CalendarTest.StrToDate(listReq.getEndDate());
            Page<AdminDocumentManageListItem> page = new Page<>(pageNo, pageSize);
            List<AdminDocumentManageListItem> list = managementService
                    .getDocumentListNotice(page, listReq.getDocumentType(), listReq.getReceiveClass(), listReq.getSeachValue(), listReq.getApproveStatus(), userId, beginDate, endDate);
            for (AdminDocumentManageListItem listItem : list) {
                if (!StringUtils.isEmpty(listItem.getContentClass())) {
                    adminEnum.receiveClass admin = Enum.valueOf(adminEnum.receiveClass.class, listItem.getContentClass());
                    if (admin != null) {
                        listItem.setContentClassName(admin.getValue());
                    }
                    Wrapper<SystemUserLogin> wrapper = new EntityWrapper<>();
                    wrapper.eq(SystemUserLogin.USERINFO_ID, listItem.getPersonId());
                    wrapper.eq(SystemUserLogin.IS_DELETED, false);
                    SystemUserLogin login = loginService.selectOne(wrapper);
                    if (login != null) {
                        SystemOrgItem orgItem = orgService.getOrgNameListByUserId(login.getId());
                        if (orgItem != null) {
                            listItem.setOrgName(orgItem.getOrgName());
                        }
                    }
                }

                listItem.setIsRead(JacksonUtil.getIsRead(listItem.getExt(), userId.toString()));
                Boolean isOffice = !roleService.getSystemRoleByRoleTagAUserId("office", userId).isEmpty();
                Boolean isDirector = !roleService.getSystemRoleByRoleTagAUserId("director", userId).isEmpty();
                Boolean isBranch = !roleService.getSystemRoleByRoleTagAUserId("branchLeader", userId).isEmpty();
                Boolean isArchivist = !roleService.getSystemRoleByRoleTagAUserId("archivist", userId).isEmpty();
                if (listItem.getActivitiStatus().equals(2L) && (listItem.getCreatedBy().equals(userId) || isArchivist)) {
                    listItem.setShowUpLoad(true);
                } else {
                    listItem.setShowUpLoad(false);
                }
                if (listItem.getActivitiStatus().equals(2L) && listItem.getExt().containsKey("formalFile") && listItem.getExt().get("formalFile") != null
                        && (listItem.getCreatedBy().equals(userId) || isArchivist || isOffice || isDirector || isBranch) ) {
                    listItem.setShowDownLoad(true);
                } else {
                    listItem.setShowDownLoad(false);
                }
            }
            AdminDocumentManagementListResp resp = new AdminDocumentManagementListResp();
            resp.setLs(list);
            resp.setPages(page.getPages());
            resp.setTotal(page.getTotal());

            return ApiResponse.fillSuccess(resp);
        } catch (Exception e) {
            log.error("AdminDocumentManagementController.edit", e);
            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_EXCEPTION_ERROR, null);
        }
    }

    @PutMapping(Api.SETREADER_ADMIN_DOCUMENT)
    public String setReader(@PathVariable("id") Long Id, @RequestHeader Long userId) throws XQException {
        AdminDocumentManagement documentManagement = managementService.selectById(Id);
        if (documentManagement == null) {
            throw new XQException(0, null);
        }
        JSONObject ext = JacksonUtil.setReader(documentManagement.getExt(), "readerList", userId.toString());
        documentManagement.setExt(ext);
        managementService.updateById(documentManagement);
        return ApiResponse.fillSuccess("添加阅读人成功");
    }


    private String getBelongModule(String receiveClass) {
        String module = "";
        switch (receiveClass) {
            case "announcement":
                module = "administration";
                break;
            case "unionActivity":
            case "employeeCare":
            case "commend":
            case "rewardsAndpunishments":
                module = "party";
                break;
            case "safetyRegister":
                module = "logistics";
                break;
            default:
                module = "administration";
                break;
        }
        return module;
    }

    @GetMapping(Api.GET_ADMIN_DOCUMENT_MANAGEMENT_NUMBER)
    public String getNumber(@PathVariable("id") Long id) throws XQException {
        SystemTerm systemTerm = systemTermService.selectById(id);
        String termName = "";
        if (systemTerm != null) {
            termName = systemTerm.getTermName();
        }
        Calendar date = Calendar.getInstance();
        String year = String.valueOf(date.get(Calendar.YEAR));
        Integer count = managementService.getCountByCategoryID(id.toString(), year);
        String result = termName + "〔" + year + "〕" + (count + 1) + "号";
        Integer cu = managementService.isExistByReceiveNum(result,null);
        if(cu > 0){
            result = termName + "〔" + year + "〕" + (count + 2) + "号";
        }
        return ApiResponse.fillSuccess(result);
    }

    @GetMapping(Api.GETNOTREADER_COUNT)
    public String getNotReadCount(@RequestHeader Long userId) throws XQException {
        Map<String, Object> countList = new HashMap<>();
        Integer noticeCount = contentService.getNotReadCount(userId, "announcement");
        Integer internalCount = managementService.getNotReadCount(0, "internalManagement", "", 2, userId, null, null);
        Integer foreignAffairsCount = managementService.getNotReadCount(0, "foreignAffairs", "", 2, userId, null, null);
        countList.put("announcement", noticeCount);
        countList.put("internalManagement", internalCount);
        countList.put("foreignAffairs", foreignAffairsCount);
        countList.put("AllCount", noticeCount + internalCount + foreignAffairsCount);
        return ApiResponse.fillSuccess(countList);
    }

    @GetMapping(Api.GETRECNOTREADER_COUNT)
    public String getRecNotReadCount(@RequestHeader Long userId) throws XQException {
        Map<String, Object> countList = new HashMap<>();
        Integer count = managementService.getRecNotReadCount(userId, 1);
        countList.put("recCount", count);

        return ApiResponse.fillSuccess(countList);
    }

    @PutMapping(Api.UPLOAD_FILE_ADMIN_DOCUMENT_MANAGEMENT)
    public String upLoadFormalFile(@PathVariable("id") Long id, @RequestBody AdminDocumentManagementReq managementReq) throws XQException {
        try {
            AdminDocumentManagement management = managementService.selectById(id);
            if (management != null) {
                JSONObject ext = managementReq.getExt();
                if (ext != null) {
                    ext.put("formalFile", managementReq.getExt().get("formalFile"));
                    management.setExt(ext);
                    managementService.updateById(management);
                }
            }
            return ApiResponse.fillSuccess("上传成功");
        } catch (Exception e) {
            log.error("AdminDocumentManagementController.get", e);
            throw new XQException(ErrorCode.ADMINDOCUMENTMANAGEMENT_EXCEPTION_ERROR, null);
        }
    }
}
